package com.taais.biz.service.impl;

import java.util.Arrays;
import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryWrapper;
import com.taais.common.core.utils.MapstructUtils;
import com.taais.common.core.utils.StringUtils;
import com.taais.common.orm.core.page.PageQuery;
import com.taais.common.core.core.page.PageResult;
import com.taais.common.orm.core.service.impl.BaseServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.taais.biz.mapper.TargetIdentificationTaskMapper;
import com.taais.biz.domain.TargetIdentificationTask;
import com.taais.biz.domain.bo.TargetIdentificationTaskBo;
import com.taais.biz.domain.vo.TargetIdentificationTaskVo;
import com.taais.biz.service.ITargetIdentificationTaskService;
import static com.taais.biz.domain.table.TargetIdentificationTaskTableDef.TARGET_IDENTIFICATION_TASK;

/**
 * 目标识别任务Service业务层处理
 *
 * @author km
 * 2024-08-17
 */
@Service
public class TargetIdentificationTaskServiceImpl extends BaseServiceImpl<TargetIdentificationTaskMapper, TargetIdentificationTask> implements ITargetIdentificationTaskService {
    @Resource
    private TargetIdentificationTaskMapper targetIdentificationTaskMapper;

    @Override
    public QueryWrapper query() {
        return super.query().from(TARGET_IDENTIFICATION_TASK);
    }

    private QueryWrapper buildQueryWrapper(TargetIdentificationTaskBo targetIdentificationTaskBo) {
        QueryWrapper queryWrapper = super.buildBaseQueryWrapper();
        queryWrapper.and(TARGET_IDENTIFICATION_TASK.NAME.like
        (targetIdentificationTaskBo.getName()));
        queryWrapper.and(TARGET_IDENTIFICATION_TASK.STATUS.eq
        (targetIdentificationTaskBo.getStatus()));
        queryWrapper.and(TARGET_IDENTIFICATION_TASK.REMARKS.eq
        (targetIdentificationTaskBo.getRemarks()));
        queryWrapper.and(TARGET_IDENTIFICATION_TASK.SYSTEM.eq
        (targetIdentificationTaskBo.getSystem()));

        return queryWrapper;
    }

    /**
     * 查询目标识别任务
     *
     * @param id 目标识别任务主键
     * @return 目标识别任务
     */
    @Override
    public TargetIdentificationTaskVo selectById(Long id) {
            return this.getOneAs(query().where(TARGET_IDENTIFICATION_TASK.ID.eq(id)), TargetIdentificationTaskVo.class);

    }

    /**
     * 查询目标识别任务列表
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 目标识别任务集合
     */
    @Override
    public List<TargetIdentificationTaskVo> selectList(TargetIdentificationTaskBo targetIdentificationTaskBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(targetIdentificationTaskBo);
            return this.listAs(queryWrapper, TargetIdentificationTaskVo.class);
    }

    /**
     * 分页查询目标识别任务列表
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 分页目标识别任务集合
     */
    @Override
    public PageResult<TargetIdentificationTaskVo> selectPage(TargetIdentificationTaskBo targetIdentificationTaskBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(targetIdentificationTaskBo);
            Page<TargetIdentificationTaskVo> page = this.pageAs(PageQuery.build(), queryWrapper, TargetIdentificationTaskVo.class);
        return PageResult.build(page);
    }

    /**
     * 新增目标识别任务
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    @Override
    public boolean insert(TargetIdentificationTaskBo targetIdentificationTaskBo) {
    TargetIdentificationTask targetIdentificationTask =MapstructUtils.convert(targetIdentificationTaskBo, TargetIdentificationTask. class);

        return this.save(targetIdentificationTask);//使用全局配置的雪花算法主键生成器生成ID值
    }

    /**
     * 修改目标识别任务
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    @Override
    public boolean update(TargetIdentificationTaskBo targetIdentificationTaskBo) {
        TargetIdentificationTask targetIdentificationTask =MapstructUtils.convert(targetIdentificationTaskBo, TargetIdentificationTask. class);
        if (ObjectUtil.isNotNull(targetIdentificationTask) && ObjectUtil.isNotNull(targetIdentificationTask.getId())){
            boolean updated = this.updateById(targetIdentificationTask);
                return updated;
        }
        return false;
    }

    /**
     * 批量删除目标识别任务
     *
     * @param ids 需要删除的目标识别任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    @Transactional
    @Override
    public boolean deleteByIds(Long[] ids) {
        return this.removeByIds(Arrays.asList(ids));
    }

    @Override
    public String createTask(Object o) {
        return null;
    }

}
